@@ -5,11 +5,11 @@ from subprocess    import call
 from PyQt4.QtCore  import Qt, QObject, SIGNAL, SLOT
 from PyQt4.QtGui   import QAbstractItemView, QCompleter, QDialog, \
                           QDialogButtonBox, QHBoxLayout, QLabel, QLineEdit, \
-                          QListWidget, QMenuBar, QPushButton, QVBoxLayout, \
-                          QWidget, QCompleter
+                          QListWidget, QMenuBar, QMessageBox, QPushButton, \
+                          QVBoxLayout, QWidget
 from ACE_file      import ACEFile;
 
-version = '0.0.1'
+version = '0.0.2'
 
 class ACEAboutWindow(QDialog): #{{{1
     def __init__(self, parent): #{{{2
@@ -155,6 +155,13 @@ class ACEMainWindow(QWidget): #{{{1
             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
 
         self._dict = ACEFile()
+
+        if not self._dict.validate():
+            res = QMessageBox.question(self, 'Dictionary file problem', 'The custom auto-complete dictionary does not match a current known format.  Please contact Robin Hill <maemo@robinhill.me.uk> to help get this format supported.  Continuing with editing may break your auto-complete functionality.  Do you wish to continue?', QMessageBox.Yes|QMessageBox.No, QMessageBox.No)
+
+            if res != QMessageBox.Yes:
+                exit()
+
         self._listView.addItems(self._dict.dictEntries)
 
         if updateSpinner:
